==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/libroccatwidget/roccat_macro_dialog.h <==
#ifndef __ROCCAT_MACRO_DIALOG_H__
#define __ROCCAT_MACRO_DIALOG_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat/roccat.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_DIALOG_TYPE (roccat_macro_dialog_get_type())
#define ROCCAT_MACRO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_DIALOG_TYPE, RoccatMacroDialog))
#define IS_ROCCAT_MACRO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_DIALOG_TYPE))

typedef struct _RoccatMacroDialog RoccatMacroDialog;
typedef struct _RoccatMacroDialogPrivate RoccatMacroDialogPrivate;

struct _RoccatMacroDialog {
	GtkDialog dialog;
	RoccatMacroDialogPrivate *priv;
};

RoccatMacro *roccat_macro_dialog(GtkWindow *parent);
RoccatMacro *roccat_macro_dialog_run(RoccatMacroDialog *macro_dialog);
RoccatMacro *roccat_macro_dialog_get_value(RoccatMacroDialog *macro_dialog);
void roccat_macro_dialog_set_macros(RoccatMacroDialog *macro_dialog, RoccatMacros *macros);
GtkWidget *roccat_macro_dialog_new(GtkWindow *parent);

G_END_DECLS

#endif

==> roccat-tools-1.4.0.tar.bz2: roccat-tools-1.4.0/libroccatwidget/roccat_macro_dialog.h <==
#ifndef __ROCCAT_MACRO_DIALOG_H__
#define __ROCCAT_MACRO_DIALOG_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_macros.h"
#include <gtk/gtk.h>

G_BEGIN_DECLS

#define ROCCAT_MACRO_DIALOG_TYPE (roccat_macro_dialog_get_type())
#define ROCCAT_MACRO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), ROCCAT_MACRO_DIALOG_TYPE, RoccatMacroDialog))
#define IS_ROCCAT_MACRO_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), ROCCAT_MACRO_DIALOG_TYPE))

typedef struct _RoccatMacroDialog RoccatMacroDialog;
typedef struct _RoccatMacroDialogPrivate RoccatMacroDialogPrivate;

struct _RoccatMacroDialog {
	GtkDialog dialog;
	RoccatMacroDialogPrivate *priv;
};

RoccatMacro *roccat_macro_dialog(GtkWindow *parent);
RoccatMacro *roccat_macro_dialog_run(RoccatMacroDialog *macro_dialog);
RoccatMacro *roccat_macro_dialog_get_value(RoccatMacroDialog *macro_dialog);
void roccat_macro_dialog_set_macros(RoccatMacroDialog *macro_dialog, RoccatMacros *macros);
GtkWidget *roccat_macro_dialog_new(GtkWindow *parent);

G_END_DECLS

#endif
